@@ -1,18 +1,13 @@
 #!python
 # The above makes the script executable.
 
-import slider.legacy_importer
 import PyPDF2
 import os
-from jinjafy import execute_command
-# from slider import slide
 from slider import legacy_importer
 from slider.legacy_importer import SVG_EDIT_RELPATH, SVG_TMP_RELPATH, move_template_files, DTU_beamer_base, svg_edit_to_importable
 from jinjafy.cache import cache_update_str, cache_contains_str, cache_contains_file, cache_update_file
 import shutil
 from slider.slide_fixer import check_svg_file_and_fix_if_broken
-from slider.latexutils import latexmk
-import clize
 import glob
 
 dc = "\\documentclass"
